@@ -1,16 +1,15 @@
 /*
  *
- *  This file is part of MUMPS 5.3.5, released
- *  on Thu Oct 22 09:29:08 UTC 2020
+ *  This file is part of MUMPS 5.2.1, released
+ *  on Fri Jun 14 14:46:05 UTC 2019
  *
  *
- *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license 
- *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
- *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
+ *  released under the CeCILL-C license:
+ *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
  *
  */
 #include <errno.h>
@@ -34,9 +33,9 @@ MUMPS_INT mumps_io_error(MUMPS_INT mumps_errno, const char* desc);
    Returns mumps_errno for convenience */
 MUMPS_INT mumps_io_sys_error(MUMPS_INT mumps_errno, const char* desc);
 #if ! ( defined(MUMPS_WIN32) || defined(WITHOUT_PTHREAD) )
-MUMPS_INT mumps_io_init_err_lock();
-MUMPS_INT mumps_io_destroy_err_lock();
-MUMPS_INT mumps_check_error_th();
+MUMPS_INT mumps_io_init_err_lock(void);
+MUMPS_INT mumps_io_destroy_err_lock(void);
+MUMPS_INT mumps_check_error_th(void);
 /*MUMPS_INLINE MUMPS_INT mumps_io_protect_err();*/ /* ssg */
 /*MUMPS_INLINE MUMPS_INT mumps_io_unprotect_err();*/ /* ssg */
 #endif /* ! ( MUMPS_WIN32 || WITHOUT_PTHREAD ) */
