@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-**
+** 
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-**
+** 
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-**
+** 
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -244,7 +244,7 @@ const int                   protnum)              /* Root process number
   vertglbmax = DATASIZE (vertglbnbr, grafptr->procglbnbr, 0);
   vertlocnbr = DATASIZE (vertglbnbr, grafptr->procglbnbr, grafptr->proclocnum);
 
-  sprintf (proptab, "%3.3d", (int) reduglbtab[4]); /* Compute file properties */
+  snprintf (proptab, 3, "%3.3d", (int) reduglbtab[4]); /* Compute file properties */
   proptab[0] -= '0';                              /* Vertex labels flag       */
   proptab[1] -= '0';                              /* Edge weights flag        */
   proptab[2] -= '0';                              /* Vertex loads flag        */
@@ -740,7 +740,7 @@ const DgraphFlag            flagval)              /* Graph loading flags
   vertlocnbr = reduloctab[10];
   edgelocnbr = reduloctab[11];
 
-  sprintf (proptab, "%3.3d", (int) reduglbtab[9]); /* Compute file properties */
+  snprintf (proptab, 3, "%3.3d", (int) reduglbtab[9]); /* Compute file properties */
   proptab[0] -= '0';                              /* Vertex labels flag       */
   proptab[1] -= '0';                              /* Edge weights flag        */
   proptab[2] -= '0';                              /* Vertex loads flag        */
