@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-**
+** 
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-**
+** 
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-**
+** 
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -40,19 +40,19 @@
 /**                syntactic analyzer.                     **/
 /**                                                        **/
 /**   DATES      : # Version 3.1  : from : 07 nov 1995     **/
-/**                                 to   : 02 may 1996     **/
+/**                                 to     02 may 1996     **/
 /**                # Version 3.2  : from : 07 oct 1996     **/
-/**                                 to   : 19 oct 1996     **/
+/**                                 to     19 oct 1996     **/
 /**                # Version 3.3  : from : 01 oct 1998     **/
-/**                                 to   : 10 sep 2001     **/
+/**                                 to     10 sep 2001     **/
 /**                # Version 4.0  : from : 20 dec 2001     **/
-/**                                 to   : 02 feb 2004     **/
+/**                                 to     02 feb 2004     **/
 /**                # Version 5.0  : from : 20 feb 2008     **/
-/**                                 to   : 20 feb 2008     **/
+/**                                 to     20 feb 2008     **/
 /**                # Version 5.1  : from : 22 oct 2008     **/
-/**                                 to   : 11 aug 2010     **/
+/**                                 to     11 aug 2010     **/
 /**                # Version 6.0  : from : 01 jun 2012     **/
-/**                                 to   : 30 dec 2016     **/
+/**                                 to     30 dec 2016     **/
 /**                                                        **/
 /************************************************************/
 
@@ -178,6 +178,9 @@ Strat * const               strat)
         }
       }
       break;
+    case STRATNODENBR :                        /* ssg */
+      break;
+
 #ifdef SCOTCH_DEBUG_PARSER2
     default :
       errorPrint ("stratExit: invalid strategy node");
@@ -287,6 +290,8 @@ FILE * const                stream)
       if ((o == 0) && (paraflag != 0))            /* If there is a parameter list */
         o |= (fprintf (stream, "}") == EOF);      /* Close it                     */
       break;
+    case STRATNODENBR :                        /* ssg */
+      break;
 #ifdef SCOTCH_DEBUG_PARSER2
     default :
       errorPrint ("stratSave: invalid strategy node");
@@ -472,6 +477,8 @@ const void * restrict const       data)           /*+ Pointer to data structure
       }
       eval->typenode = test->typenode;
       break;
+    case STRATTESTNBR :                        /* ssg */
+      break;
 #ifdef SCOTCH_DEBUG_PARSER1
     default :
       errorPrint ("stratTestEval: invalid condition type (%u)", test->typetest);
@@ -559,6 +566,8 @@ StratTest * const           test)
     case STRATTESTVAL :                           /* Constant value */
     case STRATTESTVAR :                           /* Variable       */
       break;
+    case STRATTESTNBR :                        /* ssg */
+      break;
 #ifdef SCOTCH_DEBUG_PARSER1
     default :
       errorPrint ("stratTestExit: invalid condition type (%u)", test->typetest);
@@ -652,6 +661,8 @@ FILE * const                stream)
       }
       o = (fprintf (stream, "%s", test->data.var.datatab->condtab[i].name) == EOF);
       break;
+    case STRATTESTNBR :                        /* ssg */
+      break;
 #ifdef SCOTCH_DEBUG_PARSER2
     default :
       errorPrint ("stratTestSave: invalid condition type (%u)", test->typetest);
